@@ -4,7 +4,6 @@ import os
 
 import tensorflow as tf
 
-from transformers_keras.adapters import parse_pretrained_model_files
 from transformers_keras.adapters.bert_adapter import BertAdapter
 
 from .modeling_utils import choose_activation
@@ -77,15 +76,7 @@ class BertEmbedding(tf.keras.layers.Layer):
 class BertMultiHeadAtttetion(tf.keras.layers.Layer):
     """Multi head attention."""
 
-    def __init__(
-        self,
-        hidden_size=768,
-        num_attention_heads=8,
-        attention_dropout_rate=0.1,
-        initializer_range=0.02,
-        epsilon=1e-8,
-        **kwargs
-    ):
+    def __init__(self, hidden_size=768, num_attention_heads=8, attention_dropout_rate=0.1, initializer_range=0.02, **kwargs):
         super().__init__(**kwargs)
         self.num_attention_heads = num_attention_heads
         self.hidden_size = hidden_size
@@ -176,7 +167,6 @@ class BertAttention(tf.keras.layers.Layer):
             num_attention_heads=num_attention_heads,
             attention_dropout_rate=attention_dropout_rate,
             initializer_range=initializer_range,
-            epsilon=epsilon,
             name="self",
         )
         self.attention_output = BertAttentionOutput(
@@ -402,9 +392,7 @@ class BertModel(tf.keras.layers.Layer):
         embedding = self.bert_embedding(input_ids, segment_ids, training=training)
         # (batch_size, seq_len) -> (batch_size, 1, 1, seq_len)
         attention_mask = attention_mask[:, tf.newaxis, tf.newaxis, :]
-        output, all_hidden_states, all_attention_scores = self.bert_encoder(
-            embedding, attention_mask, training=training
-        )
+        output, all_hidden_states, all_attention_scores = self.bert_encoder(embedding, attention_mask, training=training)
         pooled_output = self.bert_pooler(output)
         return output, pooled_output, all_hidden_states, all_attention_scores
 
@@ -419,6 +407,11 @@ class BertPretrainedModel(tf.keras.Model):
         override_params=None,
         use_functional_api=True,
         adapter=None,
+        with_mlm=False,
+        with_nsp=False,
+        ckpt_bert_prefix="bert",
+        ckpt_mlm_prefix="cls/predictions",
+        ckpt_nsp_prefix="cls/seq_relationship",
         check_weights=True,
         verbose=True,
         **kwargs
@@ -436,8 +429,6 @@ class BertPretrainedModel(tf.keras.Model):
             check_weights: Python boolean. If true, check model weights' value after loading weights from ckpt
             verbose: Python boolean.If True, logging more detailed informations when loadding pretrained weights
         """
-
-        config_file, ckpt, _ = parse_pretrained_model_files(pretrained_model_dir)
         if not adapter:
             adapter = BertAdapter(
                 skip_token_embedding=kwargs.pop("skip_token_embedding", False),
@@ -446,21 +437,27 @@ class BertPretrainedModel(tf.keras.Model):
                 skip_embedding_layernorm=kwargs.pop("skip_embedding_layernorm", False),
                 skip_pooler=kwargs.pop("skip_pooler", False),
             )
+        files = adapter.parse_files(pretrained_model_dir)
+        config_file = files["config_file"]
         model_config = adapter.adapte_config(config_file, **kwargs)
+        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
         if override_params:
             model_config.update(override_params)
-        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
+            logging.info("Overrided model config: \n%s", json.dumps(model_config, indent=4))
         model = cls(**model_config, **kwargs)
-        assert (
-            getattr(model, "bert_model", None) is not None
-        ), "BertPretrainedModel must have an attribute named bert_model!"
+        assert model.bert_model is not None, "bert_model is None!"
         inputs = model.dummy_inputs()
         model(inputs=list(inputs), training=False)
         adapter.adapte_weights(
-            bert=model.bert_model,
-            config=model_config,
-            ckpt=ckpt,
-            prefix="" if use_functional_api else model.name,
+            model=model,
+            ckpt=files["ckpt"],
+            model_config=model_config,
+            use_functional_api=use_functional_api,
+            with_mlm=with_mlm,
+            with_nsp=with_nsp,
+            ckpt_bert_prefix=ckpt_bert_prefix,
+            ckpt_mlm_prefix=ckpt_mlm_prefix,
+            ckpt_nsp_prefix=ckpt_nsp_prefix,
             check_weights=check_weights,
             verbose=verbose,
             **kwargs
@@ -478,17 +475,23 @@ class BertPretrainedModel(tf.keras.Model):
                 skip_pooler=kwargs.pop("skip_pooler", False),
             )
         model_config = adapter.adapte_config(config_file, **kwargs)
+        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
         if override_params:
             model_config.update(override_params)
-        logging.info("Load model config: \n%s", json.dumps(model_config, indent=4))
+            logging.info("Overrided model config: \n%s", json.dumps(model_config, indent=4))
         model = cls(**model_config, **kwargs)
-        assert (
-            getattr(model, "bert_model", None) is not None
-        ), "BertPretrainedModel must have an attribute named bert_model!"
+        assert model.bert_model is not None, "bert_model is None!"
         inputs = model.dummy_inputs()
         model(inputs=list(inputs), training=False)
         return model
 
+    @property
+    def bert_model(self):
+        for l in self.layers:
+            if isinstance(l, BertModel):
+                return l
+        return None
+
     def dummy_inputs(self):
         input_ids = tf.constant([0] * 128, dtype=tf.int32, shape=(1, 128))
         segment_ids = tf.constant([0] * 128, dtype=tf.int32, shape=(1, 128))
@@ -535,9 +538,7 @@ class Bert(BertPretrainedModel):
             epsilon=epsilon,
             name="bert",
         )
-        sequence_output, pooled_output, hidden_states, attention_weights = bert_model(
-            input_ids, segment_ids, attention_mask
-        )
+        sequence_output, pooled_output, hidden_states, attention_weights = bert_model(input_ids, segment_ids, attention_mask)
         outputs = [
             tf.keras.layers.Lambda(lambda x: x, name="sequence_output")(sequence_output),
             tf.keras.layers.Lambda(lambda x: x, name="pooled_output")(pooled_output),
@@ -549,7 +550,7 @@ class Bert(BertPretrainedModel):
 
         super().__init__(inputs=[input_ids, segment_ids, attention_mask], outputs=outputs, **kwargs)
 
-        self.bert_model = bert_model
+        # self.bert_model = bert_model
         self.vocab_size = vocab_size
         self.type_vocab_size = type_vocab_size
         self.max_positions = max_positions
